@@ -3,7 +3,7 @@ use 5.020;
 use strict;
 use warnings;
 
-our $VERSION = "1.2.0";
+our $VERSION = "1.3.0";
 
 use Moose;
 use HTTP::Tiny;
@@ -85,7 +85,7 @@ sub http_request ($self, $method, $url, $headers = {}, $content = '') {
     return $response;
 }
 
-sub run_teamcity_build ($self, $build_type_id, $properties, $build_name, $wait = 1) {
+sub start_teamcity_build ($self, $build_type_id, $properties, $build_name) {
     $build_name //= 'unnamed-build';
 
     my $build_queue_url = $self->teamcity_auth_url . '/httpAuth/app/rest/buildQueue';
@@ -114,7 +114,12 @@ sub run_teamcity_build ($self, $build_type_id, $properties, $build_name, $wait =
         $request_body,
     );
 
-    my $json = decode_json $response->{content};
+    return decode_json $response->{content};
+}
+
+sub run_teamcity_build ($self, $build_type_id, $properties, $build_name, $wait = 1) {
+
+    my $json = $self->start_teamcity_build($build_type_id, $properties, $build_name);
 
     my $build_id          = $json->{id};
     my $build_detail_href = $json->{webUrl};
@@ -198,6 +203,17 @@ sub touch ($self, $build_name, $properties = {}) {
     return $f;
 }
 
+sub touch_without_future ($self, $build_name, $properties = {}) {
+    my $teamcity_job_parameters = join(', ', map { "$_: '$properties->{$_}'" } keys %{$properties});
+    $log->info("TOUCH WITHOUT FUTURE\t$build_name($teamcity_job_parameters)");
+
+    my $result_json = $self->start_teamcity_build($self->build_id_mapping->{$build_name}, $properties, $build_name);
+    
+    $log->info("\t[$result_json->{id}]\t$result_json->{webUrl}");
+    return { id => $result_json->{id}, href => $result_json->{webUrl}, status => '', params => $properties, output => $result_json };
+}
+
+
 sub poll_teamcity_results($self) {
     $log->info('.');
 
@@ -259,7 +275,7 @@ __END__
 
 Teamcity::Executor - Executor of TeamCity build configurations
 
-=head1 SYNOPSIS
+=head1 SYNOPSIS 1 - asynchronous usage
 
     use Teamcity::Executor;
     use IO::Async::Loop;
@@ -321,6 +337,39 @@ Teamcity::Executor - Executor of TeamCity build configurations
 
     $loop->run();
 
+=head1 SYNOPSIS 2 - synchronous usage
+
+    use Teamcity::Executor;
+    use Log::Any::Adapter;
+
+    Log::Any::Adapter->set(
+        'Dispatch',
+        outputs => [
+            [
+                'Screen',
+                min_level => 'debug',
+                stderr    => 1,
+                newline   => 1
+            ]
+        ]
+    );
+
+    my $tc = Teamcity::Executor->new(
+        credentials => {
+            url  => 'https://teamcity.example.com',
+            user => 'user',
+            pass => 'password',
+        },
+        build_id_mapping => {
+            hello_world => 'playground_HelloWorld',
+            hello_name  => 'playground_HelloName',
+        }
+    );
+
+    my $resp = $tc->touch_without_future('hello_name', {});
+
+    print "id: $resp->{id}\n";
+    print "webUrl: $resp->{webUrl}\n";
 
 =head1 DESCRIPTION
 
